@@ -29,6 +29,10 @@ impl Kubectl {
             .map(|client| Self { client })
     }
 
+    pub fn from_config(config: kube::Config) -> kube::Result<Self> {
+        kube::Client::try_from(config).map(|client| Self { client })
+    }
+
     pub fn client(&self) -> kube::Client {
         self.client.clone()
     }
@@ -50,7 +54,7 @@ impl Kubectl {
         Ok(text)
     }
 
-    pub async fn load_kubeconfig_from_secret(&self, secret: &str) -> kube::Result<kube::Config> {
+    pub async fn load_config_from_secret(&self, secret: &str) -> kube::Result<kube::Config> {
         let text = self.load_text_from_secret(secret, "value").await?;
         load_config_from_text(&text)
             .await
